Alt<KT, A> mixin
Alt type class identifies an associative operation on a type constructor.
It provides an alt function used to return an alternative value when the
current one represents a failure (for example, None for Option).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
alt(
HKT< KT, A> orElse()) → HKT<KT, A> -
map<
B> (B f(A a)) → HKT< KT, B> -
Return type is
HKT<G, B>, which expresses the fact that what we return is using exactly the same type constructor represented by the brandGinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited