CommutativeGroup<T> mixin
An commutative group (also known as an abelian group) is a group whose combine operation is commutative.
See also Group
- Superclass constraints
- Group<
T> - CommutativeMonoid<
T>
- Group<
Properties
- empty → T
-
Return the identity element for this monoid.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
combine(
T x, T y) → T -
Associative operation which combines two values.
inherited
-
combineN(
T a, int n) → T -
Return
aappended to itselfntimes. Ifnis negative, then this returnsinverse(a)appended to itselfntimes.inherited -
intercalate(
T middle) → Semigroup< T> -
Return a
Semigroupwhich insertsmiddlebetween each pair of elements.inherited -
inverse(
T a) → T -
Find the inverse of
a.inherited -
isEmpty(
T a, Eq< T> eq) → bool -
Tests if
ais the identity (empty).inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
T a, T b) → T -
Remove the element
bfroma.inherited -
reverse(
) → CommutativeMonoid< T> -
Return a
CommutativeMonoidthat reverses the order.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
instance<
A> (A emptyValue, A f(A a1, A a2), A inv(A a)) → CommutativeGroup< A> -
Create a
CommutativeGroupinstance from the given function, empty value, and inverse function.override