CookieManager class

Cookie manager for HTTP requests based on CookieJar.

Inheritance

Constructors

CookieManager(CookieJar cookieJar, {bool ignoreInvalidCookies = false})

Properties

cookieJar CookieJar
The cookie jar used to load and save cookies.
final
hashCode int
The hash code for this object.
no setterinherited
ignoreInvalidCookies bool
Whether to ignore invalid cookies during parsing or saving.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadCookies(RequestOptions options) Future<String>
Load cookies in cookie string for the request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) Future<void>
Called when an exception was occurred during the request.
override
onRequest(RequestOptions options, RequestInterceptorHandler handler) Future<void>
Called when the request is about to be sent.
override
onResponse(Response response, ResponseInterceptorHandler handler) Future<void>
Called when the response is about to be resolved.
override
saveCookies(Response response) Future<void>
Save cookies from the response including redirected requests.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCookies(List<Cookie> cookies) String
Merge cookies into a Cookie string. Cookies with longer paths are listed before cookies with shorter paths.