ap<C> method
Apply the function contained inside a to change the value on the Right from
type R to a value of type C.
Implementation
@override
Either<L, C> ap<C>(covariant Either<L, C Function(R r)> a) => a.flatMap(map);
Apply the function contained inside a to change the value on the Right from
type R to a value of type C.
@override
Either<L, C> ap<C>(covariant Either<L, C Function(R r)> a) => a.flatMap(map);