bindFuture<R2> abstract method
Used to chain multiple functions that return a Future<Either>.
When this value is Right, it returns a TaskEither that will resolve to
the result of calling f.
Otherwise, if this value is Left, it returns TaskEither.left().
Implementation
TaskEither<L, R2> bindFuture<R2>(Future<Either<L, R2>> Function(R r) f);