foldLeft<C> method
This method folds the value from left to right.
Return the result of f called with b and the value of Right.
If this Either is Left, return b.
Implementation
@override
C foldLeft<C>(C b, C Function(C acc, R b) f) =>
foldMap<Endo<C>>(dualEndoMonoid(), (b) => (c) => f(c, b))(b);