FpdartOnList<T> extension
Functional programming functions on a mutable dart Iterable using fpdart.
- on
-
- List<
T>
- List<
Methods
-
dropWhileRight(
bool test(T t)) → Iterable< T> -
Available on List<
Remove all elements starting from the last as long asT> , provided by the FpdartOnList extensiontestreturnstrue. -
foldRight<
B> (B initialValue, B combine(B previousValue, T element)) → B -
Available on List<
Fold this List into a single value by aggregating each element of the list from the last to the first.T> , provided by the FpdartOnList extension -
foldRightWithIndex<
B> (B initialValue, B combine(B previousValue, T element, int index)) → B -
Available on List<
Same asT> , provided by the FpdartOnList extensionfoldRightbut provides also theindexof each mapped element in thecombinefunction. -
takeWhileRight(
bool test(T t)) → Iterable< T> -
Available on List<
Extract all elements starting from the last as long asT> , provided by the FpdartOnList extensiontestreturnstrue.