foldRightWithKey<A> method
Apply compose to all the values of this Map sorted based on the inverse of order on their key,
and return the result of combining all the intermediate values.
Implementation
A foldRightWithKey<A>(
Order<K> order,
A initial,
A Function(K key, V value, A acc) compose,
) {
final sorted = toSortedList(order).toList().reversed;
var result = initial;
for (final item in sorted) {
result = compose(item.key, item.value, result);
}
return result;
}