FpdartOnString extension

Functional programming functions on dart String using fpdart.

on

Properties

toBoolOption Option<bool>

Available on String, provided by the FpdartOnString extension

Convert this String to bool, returns None for invalid inputs.
no setter
toDoubleOption Option<double>

Available on String, provided by the FpdartOnString extension

Convert this String to double, returns None for invalid inputs.
no setter
toIntOption Option<int>

Available on String, provided by the FpdartOnString extension

Convert this String to int, returns None for invalid inputs.
no setter
toNumOption Option<num>

Available on String, provided by the FpdartOnString extension

Convert this String to num, returns None for invalid inputs.
no setter

Methods

toBoolEither<L>(L onLeft()) Either<L, bool>

Available on String, provided by the FpdartOnString extension

Convert this String to bool, returns the result of onLeft for invalid inputs.
toDoubleEither<L>(L onLeft()) Either<L, double>

Available on String, provided by the FpdartOnString extension

Convert this String to double, returns the result of onLeft for invalid inputs.
toIntEither<L>(L onLeft()) Either<L, int>

Available on String, provided by the FpdartOnString extension

Convert this String to int, returns the result of onLeft for invalid inputs.
toNumEither<L>(L onLeft()) Either<L, num>

Available on String, provided by the FpdartOnString extension

Convert this String to num, returns the result of onLeft for invalid inputs.