Group<T> mixin
A group is a monoid where each element has an inverse.
- Superclass constraints
- Monoid<
T>
- Monoid<
Properties
- empty → T
-
Return the identity element for this monoid.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
combine(
T x, T y) → T -
Associative operation which combines two values.
inherited
-
combineN(
T a, int n) → T -
Return
aappended to itselfntimes. Ifnis negative, then this returnsinverse(a)appended to itselfntimes.override -
intercalate(
T middle) → Semigroup< T> -
Return a
Semigroupwhich insertsmiddlebetween each pair of elements.inherited -
inverse(
T a) → T -
Find the inverse of
a. -
isEmpty(
T a, Eq< T> eq) → bool -
Tests if
ais the identity (empty).inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
T a, T b) → T -
Remove the element
bfroma. -
reverse(
) → Monoid< T> -
Return a
Monoidthat reverses the order.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited