getLastMonoid<T> static method
Build an instance of Monoid in which the empty value is None and the
combine function is based on the second Option if it is Some, otherwise the first.
Implementation
static Monoid<Option<T>> getLastMonoid<T>() =>
Monoid.instance(const Option.none(), (a1, a2) => a2.isNone() ? a1 : a2);