map<C> method
If running this ReaderTaskEither returns Right, then change its value from type R to
type C using function f.
Implementation
@override
ReaderTaskEither<E, L, C> map<C>(C Function(R r) f) => ap(pure(f));
If running this ReaderTaskEither returns Right, then change its value from type R to
type C using function f.
@override
ReaderTaskEither<E, L, C> map<C>(C Function(R r) f) => ap(pure(f));