evaluate method
Execute run and extract the value A.
To extract both the value and the state use run.
To extract only the state S use execute.
Implementation
Future<A> evaluate(S state) async => (await run(state)).$1;
Execute run and extract the value A.
To extract both the value and the state use run.
To extract only the state S use execute.
Future<A> evaluate(S state) async => (await run(state)).$1;