execute method
Execute run and extract the state S.
To extract both the value and the state use run.
To extract only the value A use evaluate.
Implementation
Future<S> execute(S state) async => (await run(state)).$2;
Execute run and extract the state S.
To extract both the value and the state use run.
To extract only the value A use evaluate.
Future<S> execute(S state) async => (await run(state)).$2;