run method
Extract value A and state S by passing the original state S.
To extract only the value A use evaluate.
To extract only the state S use execute.
Implementation
Future<(A, S)> run(S state) => _run(state);
Extract value A and state S by passing the original state S.
To extract only the value A use evaluate.
To extract only the state S use execute.
Future<(A, S)> run(S state) => _run(state);