map<C> method
If running this TaskOption returns Some, then change its value from type R to
type C using function f.
Implementation
@override
TaskOption<C> map<C>(C Function(R r) f) => ap(pure(f));
If running this TaskOption returns Some, then change its value from type R to
type C using function f.
@override
TaskOption<C> map<C>(C Function(R r) f) => ap(pure(f));